#
# spec file for package ghc-lens-datetime
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name lens-datetime
Name:           ghc-%{pkg_name}
Version:        0.3
Release:        8.7
Summary:        Lenses for Data.Time.* types
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-time-devel

%description
The 'lens-datetime' library provides a unified lens based accessors to the
various types in 'Data.Time.Clock', 'Data.Time.Calendar' and
'Data.Time.LocalTime'. This library only tries to make some of the common
use-cases convenient, it doesn't aim for completeness. If you want completeness
and/or efficiency try the 'thyme' package instead
(<http://hackage.haskell.org/package/thyme>).

Demonstration of basic uses.

>import Control.Lens >import Data.Time >import Data.Time.Lens > >aDay :: Day
>aDay = fromGregorian 2013 08 22 > >aLocal :: LocalTime >aLocal = LocalTime
aDay (TimeOfDay 13 45 28) > >aUTC :: UTCTime >aUTC = UTCTime aDay 7458.9

You can then do the following:

>> aLocal ^. years >2013 >> aUTC ^. months >8 >> aLocal & time .~ midnight
>2013-08-22 00:00:00 >> aUTC & days .~ 1 & months .~ 1 >2013-01-01 02:04:18.9
UTC

You can manipulate the date-time values with proper roll-over behavior via the
'FlexibleDateTime' mechanism:

>> aLocal & flexDT.months +~ 12 >2014-08-22 13:45:28 >> aUTC & flexDT.days +~
100 >2013-11-30 02:04:18.9 UTC >> aLocal & flexDT.minutes +~ 120 >2013-08-22
15:45:28 >> aLocal & flexDT %~ ((days +~ 7) . (hours +~ 2)) >2013-08-22
13:45:28.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc README.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.3 revision 0 with cabal2obs.
